/*
 * Copyright 2019 StreamThoughts.
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.streamthoughts.azkarra.api.components;

import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertTrue;

public class ComponentAttributeTest {

    @Test
    public void shouldReturnTrueWhenAttributeContainsGivenMemberAndValue() {
        ComponentAttribute attribute = new ComponentAttribute("test");
        attribute.add("member", "value", "default");
        assertTrue(attribute.contains("member"));
        assertTrue(attribute.contains("member", "value"));
    }

    @Test
    public void shouldReturnMemberValue() {
        ComponentAttribute attribute = new ComponentAttribute("test");
        attribute.add("member", "value", "default");
        assertEquals("value", attribute.stringValue("member"));
    }

    @Test
    public void shouldReturnMemberDefaultValueIfValueIsNull() {
        ComponentAttribute attribute = new ComponentAttribute("test");
        attribute.add("member", null, "default");
        assertEquals("default", attribute.stringValue("member"));
    }

}